@@ -16,7 +16,6 @@
 //!
 //! verify.claim_id(); // Get SteamID64 of an authorized user
 //!
-//! // Only available in summaries feature.
 //! // Queries the steam api for more information about the profile.
 //! verify.get_summaries();
 //! ```
@@ -43,8 +42,6 @@ pub enum Error {
     Deserialize(serde_qs::Error),
     /// Error getting a SteamID64
     ParseSteamID(String),
-    #[cfg(feature = "summaries")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "summaries")))]
     /// Error getting a player profile
     GetSummaries(String),
 }
