@@ -48,7 +48,6 @@ impl LoginData {
     }
 }
 
-#[cfg(feature = "summaries")]
 #[allow(dead_code)]
 #[derive(Debug, Clone, Deserialize)]
 pub struct PlayerSummaries {
@@ -69,13 +68,11 @@ pub struct PlayerSummaries {
     pub personastateflags: u32,
 }
 
-#[cfg(feature = "summaries")]
 #[derive(Deserialize)]
 struct SummariesPlayers {
     players: Vec<PlayerSummaries>,
 }
 
-#[cfg(feature = "summaries")]
 #[derive(Deserialize)]
 struct SummariesResponse {
     response: SummariesPlayers,
@@ -130,8 +127,6 @@ impl Verify {
     }
 
     /// Query the Steam API to get a player profile
-    #[cfg(feature = "summaries")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "summaries")))]
     pub async fn get_summaries(&self, apikey: &str) -> Result<PlayerSummaries, Error> {
         let steamid = self.claimed_id.to_string();
 
